﻿using ElectricLocomotive;
using ProjectElectricLocomotive.DrawingObjects;
using ProjectElectricLocomotive.Generics;
using ProjectElectricLocomotive.MovementStrategy;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;


namespace ProjectElectricLocomotive
{
    public partial class FormLocomotiveCollections : Form
    {
        private readonly LocomotiveGenericStorage _storage;
        public FormLocomotiveCollections()
        {
            InitializeComponent();
            _storage = new LocomotiveGenericStorage(pictureBoxCollections.Width, pictureBoxCollections.Height);
        }

        /// <summary>
        /// Заполнение listBoxObjects
        /// </summary>
        private void ReloadObjects()
        {
            int index = listBoxStorage.SelectedIndex;

            listBoxStorage.Items.Clear();
            for (int i = 0; i < _storage.Keys.Count; i++)
            {
                listBoxStorage.Items.Add(_storage.Keys[i]);
            }
            if (listBoxStorage.Items.Count > 0 && (index == -1 || index >= listBoxStorage.Items.Count))
            {
                listBoxStorage.SelectedIndex = 0;
            }
            else if (listBoxStorage.Items.Count > 0 && index > -1 && index < listBoxStorage.Items.Count)
            {
                listBoxStorage.SelectedIndex = index;
            }
        }

        private void ButtonAddObject_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(textBoxStorageName.Text))
            {
                MessageBox.Show("Не всё заполнено", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            _storage.AddSet(textBoxStorageName.Text);
            ReloadObjects();
        }

        private void listBoxStorage_SelectedIndexChanged(object sender, EventArgs e)
        {
            pictureBoxCollections.Image = _storage[listBoxStorage.SelectedItem?.ToString() ?? string.Empty]?.ShowLocomotives();
        }

        private void ButtonRemoveObject_Click(object sender, EventArgs e)
        {
            if (listBoxStorage.SelectedIndex == -1)
            {
                return;
            }
            if (MessageBox.Show($"Удалить объект {listBoxStorage.SelectedItem}?", "Удаление", MessageBoxButtons.YesNo,
                MessageBoxIcon.Question) == DialogResult.Yes)
            {
                _storage.DelSet(listBoxStorage.SelectedItem.ToString() ?? string.Empty);
                ReloadObjects();
            }
        }

        private void ButtonAddLocomotive_Click(object sender, EventArgs e)
        {
            var formLocomotiveConfig = new FormLocomotiveConfig();
            formLocomotiveConfig.AddEvent(addLoco);
            formLocomotiveConfig.Show();
        }

        public void addLoco(DrawingLocomotive loco)
        {
            loco._pictureWidth = pictureBoxCollections.Width;
            loco._pictureHeight = pictureBoxCollections.Height;

            if (listBoxStorage.SelectedIndex == -1) return;

            var obj = _storage[listBoxStorage.SelectedItem.ToString() ?? string.Empty];
            if (obj == null)
            {
                return;
            }

            //проверяем, удалось ли нам загрузить объект
            if (obj + loco > -1)
            {
                MessageBox.Show("Объект добавлен");
                pictureBoxCollections.Image = obj.ShowLocomotives();
            }
            else
            {
                MessageBox.Show("Не удалось добавить объект");
            }
        }

        private void ButtonRemoveLocomotive_Click(object sender, EventArgs e)
        {
            if (listBoxStorage.SelectedIndex == -1) return;
            var obj = _storage[listBoxStorage.SelectedItem.ToString() ?? string.Empty];
            if (obj == null)
            {
                return;
            }

            if (MessageBox.Show("Удалить объект?", "Удаление", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
            {
                return;
            }
            int pos = Convert.ToInt32(maskedTextBoxNumber.Text);
            if (obj - pos != null)
            {
                MessageBox.Show("Объект удален");
                pictureBoxCollections.Image = obj.ShowLocomotives();
            }
            else
            {
                MessageBox.Show("Не удалось удалить объект");
            }
        }

        private void ButtonRefreshCollection_Click(object sender, EventArgs e)
        {
            if (listBoxStorage.SelectedIndex == -1) return;
            var obj = _storage[listBoxStorage.SelectedItem.ToString() ?? string.Empty];
            if (obj == null)
            {
                return;
            }
            pictureBoxCollections.Image = obj.ShowLocomotives();
        }
    }
}
